@@ -18,6 +18,8 @@
 #'   for examples. \code{\link{rec_pattern}} is a convenient function to
 #'   create recode strings for grouping variables.
 #' @param as.num Logical, if \code{TRUE}, return value will be numeric, not a factor.
+#' @param to.factor Logical, alias for \code{as.num}. If \code{TRUE}, return value
+#'   will be a factor, not numeric.
 #' @param var.label Optional string, to set variable label attribute for the
 #'   returned variable (see vignette \href{https://cran.r-project.org/package=sjlabelled/vignettes/intro_sjlabelled.html}{Labelled Data and the sjlabelled-Package}).
 #'   If \code{NULL} (default), variable label attribute of \code{x} will
@@ -42,8 +44,6 @@
 #'     \item grouped variables (\code{group_var()}) will be suffixed with \code{"_gr"}
 #'     \item standardized variables (\code{std()}) will be suffixed with \code{"_z"}
 #'     \item centered variables (\code{center()}) will be suffixed with \code{"_c"}
-#'     \item de-meaned variables (\code{de_mean()}) will be suffixed with \code{"_dm"}
-#'     \item grouped-meaned variables (\code{de_mean()}) will be suffixed with \code{"_gm"}
 #'   }
 #'   If \code{suffix = ""} and \code{append = TRUE}, existing variables that
 #'   have been recoded/transformed will be overwritten.
@@ -179,20 +179,22 @@
 #' p <- function(x) min(x, na.rm = TRUE) > 0 && max(x, na.rm = TRUE) < 5
 #' out <- rec_if(efc, predicate = p, rec = "1:3=1;4=2;else=copy")
 #' head(out)
-#' @importFrom insight print_color
 #' @export
-rec <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r") {
+rec <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r", to.factor = !as.num) {
   UseMethod("rec")
 }
 
 
-#' @importFrom dplyr quos
 #' @export
-rec.default <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r") {
+rec.default <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r", to.factor = !as.num) {
 
   # evaluate arguments, generate data
   .dat <- get_dot_data(x, dplyr::quos(...))
 
+  if (!missing(to.factor)) {
+    as.num <- !to.factor
+  }
+
   rec_core_fun(
     x = x,
     .dat = .dat,
@@ -206,13 +208,15 @@ rec.default <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels
 }
 
 
-#' @importFrom dplyr bind_cols select quos
-#' @importFrom purrr map
 #' @export
-rec.mids <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r") {
+rec.mids <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r", to.factor = !as.num) {
   vars <- dplyr::quos(...)
   ndf <- prepare_mids_recode(x)
 
+  if (!missing(to.factor)) {
+    as.num <- !to.factor
+  }
+
   # select variable and compute rowsums. add this variable
   # to each imputed
 
@@ -239,14 +243,16 @@ rec.mids <- function(x, ..., rec, as.num = TRUE, var.label = NULL, val.labels =
 }
 
 
-#' @importFrom dplyr select_if
 #' @rdname rec
 #' @export
-rec_if <- function(x, predicate, rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r") {
+rec_if <- function(x, predicate, rec, as.num = TRUE, var.label = NULL, val.labels = NULL, append = TRUE, suffix = "_r", to.factor = !as.num) {
 
   # select variables that match logical conditions
   .dat <- dplyr::select_if(x, .predicate = predicate)
 
+  if (!missing(to.factor)) {
+    as.num <- !to.factor
+  }
 
   # if no variable matches the condition specified
   # in predicate, return original data
@@ -286,7 +292,8 @@ rec_core_fun <- function(x, .dat, rec, as.num = TRUE, var.label = NULL, val.labe
         recodes = rec,
         as.num = as.num,
         var.label = var.label,
-        val.labels = val.labels
+        val.labels = val.labels,
+        column_name = i
       )
     }
 
@@ -309,9 +316,7 @@ rec_core_fun <- function(x, .dat, rec, as.num = TRUE, var.label = NULL, val.labe
 }
 
 
-#' @importFrom stats na.omit
-#' @importFrom sjlabelled drop_labels get_na get_label get_labels set_label set_labels
-rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
+rec_helper <- function(x, recodes, as.num, var.label, val.labels, column_name = NULL) {
   # retrieve variable label
   if (is.null(var.label))
     var_lab <- sjlabelled::get_label(x)
@@ -321,6 +326,15 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
   # do we have any value labels?
   val_lab <- val.labels
 
+  if (all_na(x)) {
+    if (!is.null(column_name)) {
+      msg <- paste0("Variable '", column_name, "' has no non-missing values.")
+    } else {
+      msg <- "Variable has no non-missing values."
+    }
+    warning(insight::format_message(msg), call. = FALSE)
+  }
+
   # remember if NA's have been recoded...
   na_recoded <- FALSE
 
@@ -367,8 +381,8 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
 
 
   # retrieve min and max values
-  min_val <- min(x, na.rm = T)
-  max_val <- max(x, na.rm = T)
+  min_val <- suppressWarnings(min(x, na.rm = TRUE))
+  max_val <- suppressWarnings(max(x, na.rm = TRUE))
 
   # do we have special recode-token?
   if (recodes_reversed) {
@@ -399,10 +413,10 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
       gregexpr(
         pattern = "=([^\\]]*)\\]",
         text = recodes,
-        perl = T
+        perl = TRUE
       )
     )),
-    split = "\\[", perl = T
+    split = "\\[", perl = TRUE
   ),
   function(x) {
     tmp <- as.numeric(trim(substr(x[1], 2, nchar(x[1]))))
@@ -430,8 +444,8 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
   rec_string <- gsub(" ", "", rec_string, useBytes = TRUE, fixed = TRUE)
 
   # remove line breaks
-  rec_string <- gsub("\n", "", rec_string, useBytes = TRUE, fixed = F)
-  rec_string <- gsub("\r", "", rec_string, useBytes = TRUE, fixed = F)
+  rec_string <- gsub("\n", "", rec_string, useBytes = TRUE, fixed = FALSE)
+  rec_string <- gsub("\r", "", rec_string, useBytes = TRUE, fixed = FALSE)
 
   # replace min and max placeholders
   rec_string <- gsub("(\\blo\\b)(.*)=(.*)", paste0(as.character(min_val), "\\2=\\3"), rec_string, useBytes = TRUE, perl = TRUE)
@@ -452,7 +466,7 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
 
   # found any errors in syntax?
   if (!is.null(correct_syntax)) {
-    stop(sprintf("?Syntax error in argument \"%s\"", paste(correct_syntax, collapse = "=")), call. = F)
+    stop(sprintf("?Syntax error in argument \"%s\"", paste(correct_syntax, collapse = "=")), call. = FALSE)
   }
 
 
@@ -512,11 +526,11 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
       } else if (length(grep(":", ovs, fixed = TRUE)) > 0) {
         # this value indicates a range of values to be recoded, because
         # we have found a colon. now copy from and to values from range
-        from <- suppressWarnings(as.numeric(unlist(strsplit(ovs, ":", fixed = T))[1]))
-        to <- suppressWarnings(as.numeric(unlist(strsplit(ovs, ":", fixed = T))[2]))
+        from <- suppressWarnings(as.numeric(unlist(strsplit(ovs, ":", fixed = TRUE))[1]))
+        to <- suppressWarnings(as.numeric(unlist(strsplit(ovs, ":", fixed = TRUE))[2]))
         # check for valid range values
         if (is.na(from) || is.na(to)) {
-          stop(sprintf("?Syntax error in argument \"%s\"", ovs), call. = F)
+          stop(sprintf("?Syntax error in argument \"%s\"", ovs), call. = FALSE)
         }
         # to lower than from?
         if (from > to) {
@@ -572,8 +586,8 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
       } else if (is.character(old_val[k]) && with_dec) {
         # this value indicates a range of values to be recoded, because
         # we have found a colon. now copy from and to values from range
-        from <- suppressWarnings(as.numeric(unlist(strsplit(old_val[k], ":", fixed = T))[1]))
-        to <- suppressWarnings(as.numeric(unlist(strsplit(old_val[k], ":", fixed = T))[2]))
+        from <- suppressWarnings(as.numeric(unlist(strsplit(old_val[k], ":", fixed = TRUE))[1]))
+        to <- suppressWarnings(as.numeric(unlist(strsplit(old_val[k], ":", fixed = TRUE))[2]))
         # if old_val is a character, we assume we have a double with decimal
         # points and want to recode a range
         new_var[which(x >= from & x <= to)] <- new_val
@@ -593,6 +607,58 @@ rec_helper <- function(x, recodes, as.num, var.label, val.labels) {
     val_lab <- reversed_value_labels
   }
 
+
+  # if we have no value labels and there is a 1 to 1 correspondence between old and new values, keep the old labels with the related new values
+  if(is.null(val_lab)) {
+    old_values <- sapply(rec_pairs, function(item) item[1])
+    new_values <- sapply(rec_pairs, function(item) item[2])
+    num_ovs <- suppressWarnings(as.numeric(old_values))
+    num_nvs <- suppressWarnings(as.numeric(new_values))
+    lab_log <- c()
+
+    # all numeric or NA or else=copy
+    lab_log <- c(lab_log, length(old_values) == sum(!is.na(num_ovs) | old_values == "NA" | (new_values == "copy" & old_values == "else")))
+    lab_log <- c(lab_log, length(new_values) == sum(!is.na(num_nvs) | new_values == "NA" | (new_values == "copy" & old_values == "else")))
+
+    # at most 2 distinct non-numeric elements (which only can be NA or else=copy)
+    lab_log <- c(lab_log, sum(is.na(num_ovs)) == 0 || identical(old_values[is.na(num_ovs)], "NA") || identical(old_values[is.na(num_ovs)], "else") || (setequal(old_values[is.na(num_ovs)],c("else","NA")) & sum(is.na(num_ovs)) == 2))
+    lab_log <- c(lab_log, sum(is.na(num_nvs)) == 0 || identical(new_values[is.na(num_nvs)], "NA") || identical(new_values[is.na(num_nvs)], "copy") || (setequal(new_values[is.na(num_nvs)],c("copy","NA")) & sum(is.na(num_nvs)) == 2))
+
+    # all numeric values distinct
+    lab_log <- c(lab_log, length(num_ovs[!is.na(num_ovs)]) == length(unique(num_ovs[!is.na(num_ovs)])))
+    lab_log <- c(lab_log, length(num_nvs[!is.na(num_nvs)]) == length(unique(num_nvs[!is.na(num_nvs)])))
+
+
+    if(all(lab_log)) {
+      value_labels <- sjlabelled::get_labels(
+        x,
+        attr.only = TRUE,
+        values = "n",
+        non.labelled = FALSE,
+        drop.na = TRUE
+      )
+      nullw <- which(names(value_labels) %in% old_values[which(new_values=="NA")])
+      if(length(nullw) != 0) {
+        value_labels <- value_labels[-nullw] # remove possible label mapped to NA
+      }
+      if("else=copy" %in% rec_string && length(intersect(setdiff(names(value_labels), old_values), new_values)) == 0) {
+        new_value_labels <- value_labels
+      } else if(!"else=copy" %in% rec_string){
+        new_value_labels <- value_labels <- value_labels[which(names(value_labels) %in% old_values)]
+      } else {
+        new_value_labels <- value_labels <- NULL # don't keep labels, since there are new values which should keep the labels from multiple old values
+      }
+      ivl <- intersect(old_values, names(value_labels))
+      for(nvl in ivl) {
+        names(new_value_labels)[which(names(value_labels) == nvl)] <- new_values[which(old_values == nvl)]
+      }
+      val_lab <- new_value_labels
+    }
+  }
+
+
+
+
   # add back NA labels
   if (!is.null(current.na) && length(current.na) > 0) {
     # add named missings
